/*
 * @Date: 2022-01-14 09:15:21
 * @LastEditors: JinxChen
 * @LastEditTime: 2022-05-10 10:24:06
 * @FilePath: \AntpayFrontEnd\src\config\map\index.js
 * @description:
 */
import { AMapKey, AMapJsCode } from './models';

/**
 * @param isSync 异步加载
 * @param plugins 字符串数组格式 [ 'AMap.Geocoder', ... ]
 * @returns {Promise}
 * @constructor
 */
export default function MapLoader(isSync = false, plugins = []) {
    return new Promise((resolve, reject) => {
        try {
            if (window.AMap && (plugins === null || plugins === undefined || plugins.length === 0)) {
                resolve(window.AMap)
            } else {
                let script = document.createElement('script');
                script.type = 'text/javascript';
                script.async = !isSync;
                script.src = `https://webapi.amap.com/maps?v=1.4.15&callback=initAMap&key=${AMapKey}&plugin=AMap.BezierCurveEditor${plugins ? ',' + plugins.join(',') : ''}`;
                script.onerror = reject;
                document.head.appendChild(script);

                let script1 = document.createElement('script');
                script1.type = 'text/javascript';
                script1.async = false;
                script1.src = 'https://webapi.amap.com/ui/1.0/main.js?v=1.0.11';
                script1.onerror = reject;
                if (isSync) {
                    document.head.appendChild(script1);
                }
            }
            window.initAMap = () => resolve(window.AMap);

            // JSAPI key搭配静态安全密钥以明文设置, 详情见: https://lbs.amap.com/api/jsapi-v2/guide/abc/load
            window._AMapSecurityConfig = {
                securityJsCode: `${AMapJsCode}`,
            }
        } catch (e) {
            console.log(e);
        }

    })
}